# __python2 macro defined from Fedora 16 onwards
# __python3 always defined where Python 3 is available, but this definition quietens rpmbuild when python3 is not installed
%{!?__python2: %global __python2 python2}
%{!?__python3: %global __python3 python3}

# python3 support from F-13, EL-7
%if 0%{?fedora} > 12 || 0%{?rhel} > 6
%global with_python3 1
%endif

# Single python3 version in Fedora, python3_pkgversion macro not available
%{!?python3_pkgversion:%global python3_pkgversion 3}

# For consistency and completeness
%global python2_pkgversion 2

# Old distros don't have these
%{!?__python2:%global __python2 /usr/bin/python2}
%{!?python2_sitearch:%global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))" 2>/dev/null)}

Summary:	Python bindings for OpenBSD's Blowfish password hashing code
Name:		py-bcrypt
Version:	0.4
Release:	22%{?dist}
License:	BSD with advertising
URL:		https://code.google.com/archive/p/py-bcrypt/
Source:		https://pypi.python.org/packages/source/p/py-bcrypt/py-bcrypt-0.4.tar.gz
BuildRequires:	gcc
BuildRequires:	python%{python2_pkgversion} >= 2.6, python%{python2_pkgversion}-devel
%if 0%{?with_python3}
BuildRequires:	python%{python3_pkgversion}, python%{python3_pkgversion}-devel
%endif

# Filter unwanted provides
%global __provides_exclude_from ^%{_datadir}/py-bcrypt/.*$
%global __provides_exclude_from %__provides_exclude_from|^%{python2_sitearch}/.*\\.so$
%if 0%{?with_python3}
%global __provides_exclude_from %__provides_exclude_from|^%{python3_sitearch}/.*\\.so$
%endif

%global general_description\
python-bcrypt is a Python wrapper of OpenBSD's Blowfish password hashing\
code, as described in "A Future-Adaptable Password Scheme" by Niels\
Provos and David Mazières.\
\
This system hashes passwords using a version of Bruce Schneier's Blowfish\
block cipher with modifications designed to raise the cost of off-line\
password cracking and frustrate fast hardware implementation. The\
computation cost of the algorithm is parameterized, so it can be increased\
as computers get faster. The intent is to make a compromise of a password\
database less likely to result in an attacker gaining knowledge of the\
plain-text passwords (e.g. using John the Ripper).


%description %{general_description}

%package -n python%{python2_pkgversion}-py-bcrypt
Summary:	Python 2 bindings for OpenBSD's Blowfish password hashing code
Provides:	py-bcrypt = %{version}-%{release}
Provides:	py-bcrypt%{?_isa} = %{version}-%{release}
Obsoletes:	py-bcrypt < %{version}-%{release}

%description -n python%{python2_pkgversion}-py-bcrypt %{general_description}

This package allows for use of py-bcrypt with Python 2.

%if 0%{?with_python3}
%package -n python%{python3_pkgversion}-py-bcrypt
Summary:	Python 3 bindings for OpenBSD's Blowfish password hashing code

%description -n python%{python3_pkgversion}-py-bcrypt %{general_description}

This package allows for use of py-bcrypt with Python 3.
%endif

%prep
%setup -q -n %{name}-%{version}

%build
%{__python2} setup.py build
%if 0%{?with_python3}
%{__python3} setup.py build
%endif

%install
%{__python2} setup.py install -O1 --skip-build --root="%{buildroot}" --prefix="%{_prefix}"
chmod 755 %{buildroot}%{python2_sitearch}/bcrypt/*.so
%if 0%{?with_python3}
%{__python3} setup.py install -O1 --skip-build --root="%{buildroot}" --prefix="%{_prefix}"
chmod 755 %{buildroot}%{python3_sitearch}/bcrypt/*.so
%endif

%check
cd test
PYTHONPATH=%{buildroot}%{python2_sitearch} %{__python2} test.py
%if 0%{?with_python3}
PYTHONPATH=%{buildroot}%{python3_sitearch} %{__python3} test.py
%endif

%files -n python%{python2_pkgversion}-py-bcrypt
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc README TODO
%{python2_sitearch}/bcrypt/
%{python2_sitearch}/py_bcrypt-%{version}-py2*.egg-info

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-py-bcrypt
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc README TODO
%{python3_sitearch}/bcrypt/
%{python3_sitearch}/py_bcrypt-%{version}-py3.*.egg-info
%endif

%changelog
* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 0.4-22
- Rebuild for Python 3.8 in Rawhide

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 0.4-20
- BR: gcc

* Wed Jul 11 2018 Paul Howarth <paul@city-fan.org> - 0.4-16
- Rebuild for Python 3.7 in Rawhide

* Thu Mar 15 2018 Paul Howarth <paul@city-fan.org> - 0.4-15
- Rename Python 2 package to python2-py-bcrypt
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3
- Add Python 3.4 build for EL-7
- Use %%license where possible
- Update URL to reflect archiving of Google Code projects
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Dec 24 2016 Paul Howarth <paul@city-fan.org> - 0.4-9
- Rebuild for Python 3.6 in Rawhide

* Sat Nov 14 2015 Paul Howarth <paul@city-fan.org> - 0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu May 29 2014 Paul Howarth <paul@city-fan.org> - 0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Wed Jan  1 2014 Paul Howarth <paul@city-fan.org> - 0.4-2
- Import from Fedora

* Tue Nov 19 2013 Jon Ciesla <limburgher@gmail.com> - 0.4-1
- Latest upstream, added support for Python 3 and two new functions:
  bcrypt.checkpw() and bcrypt.kdf()

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Mar 26 2013 Jon Ciesla <limburgher@gmail.com> - 0.3-1
- Latest upstream, fixes CVE-2013-1895: concurrency issue leading to auth bypass

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Aug 17 2010 david.r@ultracar.co.uk - 0.2-4
- Altered spec file to allow building across py2.6 and py2.7

* Thu Aug 12 2010 dcr226@fedorapeople.org - 0.2-3
- Rebuilt for python 2.7

* Wed Aug 11 2010 dcr226@fedoraproject.org - 0.2-2
- packaged for Fedora

*Mon Jun 14 2010 djm@mindrot.org
- (djm) Prefer setuptools for packaging. Based on patch from Niall
   O'Higgins.
- (djm) Release py-bcrypt-0.2

*Thu Oct 01 2009 djm@mindrot.org
- (djm) Allow Python threads to run during (potentially lengthy) bcrypt
   operation. Patch from vijay AT meebo-inc.com

*Tue Aug 08 2006 djm@mindrot.org
- (djm) Add support for Win32

*Mon May 22 2006 djm@mindrot.org
- (djm) Start
